
import logging
from loguru import logger
import sys



class InterceptHandler(logging.Handler):
    def emit(self, record):
        # 获取对应的Loguru日志级别
        try:
            level = logger.level(record.levelname).name
        except ValueError:
            level = record.levelno

        # 查找日志来源
        frame, depth = logging.currentframe(), 2
        while frame and frame.f_code.co_filename == logging.__file__:
            frame = frame.f_back
            depth += 1

        # 使用Loguru记录日志
        logger.opt(depth=depth, exception=record.exc_info).log(level, record.getMessage())


def setup_logging():
    # 拦截标准logging
    logging.basicConfig(handlers=[InterceptHandler()], level=logging.NOTSET)

    # 移除所有现有处理器
    logger.remove()

    # 直接添加处理器（避免configure方法）
    logger.add(
        sys.stdout,
        format=(
            "<green>{time:YYYY-MM-DD HH:mm:ss.SSS}</green> | "
            "<level>{level: <8}</level> | "
            "<cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - "
            "<level>{message}</level>"
        ),
        level="DEBUG",
        enqueue=True
    )